API Docs
========

Models
------

.. autoclass:: django_ram.models.Role
    :members:
    :exclude-members: id, objects
    :undoc-members: name, description
    :show-inheritance:


.. autoclass:: django_ram.models.RolesMixin
    :members:
    :show-inheritance:

               

Admin
-----       

.. automodule:: django_ram.admin
    :members:
    :undoc-members:
    :show-inheritance:

Definition
----------

.. automodule:: django_ram.definition
    :members:
    :undoc-members:
    :show-inheritance:


REST Framework integration
--------------------------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   rest_framework
